Trait IntoArc

pub trait IntoArc<T> {
    // Required method
    fn into_arc(self) -> Arc<T>;
}
Make it possible to pass &x or x to a function, where x is Arc<T>, and have the function do the clone operation when needed.

Required Methods

fn into_arc(self) -> Arc<T>

Implementations on Foreign Types

Source

impl<T> IntoArc<T> for &Arc<T>

Source

fn into_arc(self) -> Arc<T>

Source

impl<T> IntoArc<T> for Arc<T>

Source

fn into_arc(self) -> Arc<T>

Implementors

Source

impl<T> IntoArc<T> for T