pub trait IntoArc<T> { // Required method fn into_arc(self) -> Arc<T>; }
Make it possible to pass &x or x to a function, where x is Arc<T>, and have the function do the clone operation when needed.
Arc<T>